=========
Changelog
=========

Version 0.1.2
=============

- Package pushed to `PyPi <https://pypi.org/project/epivizFileServer/>`_
- Updated readme and documentation


Version 0.1
===========

- First release!
